``rabbitmq`` module
===================

.. module:: flask_signalbus.rabbitmq

This module contains utilities for processing RabbitMQ messages.


Classes
```````

.. autoclass:: Publisher
   :members:

.. autoclass:: Message
   :members:

.. autoclass:: MessageProperties
   :members:


Exceptions
``````````

.. autoclass:: DeliveryError
   :members:
   :show-inheritance:

.. autoclass:: ConnectionError
   :members:
   :show-inheritance:

.. autoclass:: TimeoutError
   :members:
   :show-inheritance:
